View source: R/3_feature_network.R
| generate_feature_network | R Documentation |
generate_feature_network() generates a network of target genes that are regulated
by the previously generated TFs, and also a separate network of housekeeping genes (HKs).
feature_network_default() is used to configure parameters pertaining this process.
generate_feature_network(model)
feature_network_default(
realnet = NULL,
damping = 0.01,
target_resampling = Inf,
max_in_degree = 5
)
model |
A dyngen intermediary model for which the transcription network has been generated with |
realnet |
The name of a gene regulatory network (GRN) in realnets.
If |
damping |
A damping factor used for the page rank algorithm used to subsample the realnet. |
target_resampling |
How many targets / HKs to sample from the realnet per iteration. |
max_in_degree |
The maximum in-degree of a target / HK. |
A dyngen model.
dyngen on how to run a complete dyngen simulation
model <-
initialise_model(
backbone = backbone_bifurcating(),
feature_network = feature_network_default(damping = 0.1)
)
data("example_model")
model <- example_model |>
generate_tf_network() |>
generate_feature_network()
plot_feature_network(model)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.