kinetics_noise: Add small noise to the kinetics of each simulation

kinetics_noise_noneR Documentation

Add small noise to the kinetics of each simulation

Description

Add small noise to the kinetics of each simulation

Usage

kinetics_noise_none()

kinetics_noise_simple(mean = 1, sd = 0.005)

Arguments

mean

The mean level of noise (should be 1)

sd

The sd of the noise (should be a relatively small value)

Value

A list of noise generators for the kinetics.


dyngen documentation built on April 1, 2026, 9:07 a.m.