plot_gold_mappings: Visualise the mapping of the simulations to the gold standard

View source: R/plotting.R

plot_gold_mappingsR Documentation

Visualise the mapping of the simulations to the gold standard

Description

Visualise the mapping of the simulations to the gold standard

Usage

plot_gold_mappings(
  model,
  selected_simulations = NULL,
  do_facet = TRUE,
  mapping = aes(.data$comp_1, .data$comp_2)
)

Arguments

model

A dyngen intermediary model for which the simulations have been run with generate_cells().

selected_simulations

Which simulation indices to visualise.

do_facet

Whether or not to facet according to simulation index.

mapping

Which components to plot.

Value

A ggplot2 object.

Examples


data("example_model")
plot_gold_mappings(example_model)


dyngen documentation built on April 1, 2026, 9:07 a.m.